set more off
 
* Analyze Phone sample
use PublicReplicationDataset.dta, clear

* Rates of getting treated by strata/vote history
table  a_phone_treat_relplacebo_passed vf_state if strata_sum~=1 & strata_sum ~=2 , c(mean strata_treat_comprate)

tab vf_state, gen(sd_)
drop sd_1

*generate a new variable, which is any treatment except placebo
gen not_placebo_treat=.
replace not_placebo_treat=0 if a_phone_treat_relplacebo_passed==0
replace not_placebo_treat=1 if a_phone_treat_relplacebo_passed>0 & a_phone_treat_relplacebo_passed~=.

* Look at distribution of cases by vote history. Not enough observations to use never voters
tab assigned_phone_treat strata_sum
tab strata_sum if strata_sum~=1 & strata_sum ~=2
tab assigned_phone_treat strata if strata_sum~=1 & strata_sum ~=2

*Counts of general and primary turnout
gen d_genvotes=vt_08_gn+vt_09_gn+vt_10_gn+vt_11_gn+vt_12_gn
label var d_genvotes "Total General Election Votes"
gen d_primvotes=vt_08_pm+vt_10_pm+vt_12_pm+vt_08_pres_pm+vt_12_pres_pm
label var d_primvotes "Total Primary Election Votes"
gen d_specvotes=vt_08_sp+vt_09_sp+vt_10_sp+vt_11_sp+vt_12_sp
label var d_specvotes "Total Special Election Votes"


*******************************************************
* Table S1: Balance Tests
*******************************************************

* Mlogit Balance Tests, without and with strata fixed effects
mlogit assigned_phone_treat_withcontrol d_yearssincereg d_yearssincereg_miss d_electiondayage d_gender_male d_gender_unknown d_race_black d_race_latino d_race_miss d_race_other d_genvotes d_primvotes d_specvotes [pweight=weight_earlystatestreats], robust baseoutcome(1)
test d_yearssincereg d_yearssincereg_miss d_electiondayage d_gender_male d_gender_unknown d_race_black d_race_latino d_race_miss d_race_other d_genvotes d_primvotes d_specvotes

mlogit assigned_phone_treat_withcontrol d_yearssincereg d_yearssincereg_miss d_electiondayage d_gender_male d_gender_unknown d_race_black d_race_latino d_race_miss d_race_other d_genvotes d_primvotes d_specvotes i.strata [pweight=weight_earlystatestreats], robust baseoutcome(1)
test d_yearssincereg d_yearssincereg_miss d_electiondayage d_gender_male d_gender_unknown d_race_black d_race_latino d_race_miss d_race_other d_genvotes d_primvotes d_specvotes
gen pval_balance_earlystatetreats=e(p) 
label var pval_balance_earlystatetreats "P-value of Chi2 test from Mlogit for all covariates predicting assignment"

* These are early primary states in which all treatments were run. Treatment assignment rates were the same in these states. Weighting to deal with any remaining imbalance
foreach treat of varlist t_placebo t_info_only t_labeledasvoting t_labeledasvoter {
 local templabel : var label `treat'
 di "`templabel'"
 if "`treat'"=="t_placebo" {
 outsum d_yearssincereg d_yearssincereg_miss d_electiondayage d_gender_male d_gender_unknown d_race_black d_race_latino d_race_miss d_race_other d_genvotes d_primvotes d_specvotes pval_balance_earlystatetreats [aweight=weight_earlystatestreats] using "Tables\S1_Appendix_PhoneBalance" if `treat'==1, bracket ctitle("`templabel'") replace
 }
 else {
 outsum d_yearssincereg d_yearssincereg_miss d_electiondayage d_gender_male d_gender_unknown d_race_black d_race_latino d_race_miss d_race_other d_genvotes d_primvotes d_specvotes pval_balance_earlystatetreats [aweight=weight_earlystatestreats] using "Tables\S1_Appendix_PhoneBalance" if `treat'==1, bracket ctitle("`templabel'") append
 }
}

*******************************************************
* Table S2: Effect of Treatment on Survey Item Responses
*******************************************************

gen voter_not_voting=0 if t_labeledasvoting==1
replace voter_not_voting=1 if t_labeledasvoter==1
label var voter_not_voting "Voter treatment versus Voting treatment (1=Voter, 0=Voting)"

replace T8_q35=T9_q46 if T8_q35==.
replace T8_q36=T9_q47 if T8_q36==.
replace T8_q37=T9_q48 if T8_q37==.
replace T8_q38=T9_q49 if T8_q38==.
replace T8_q39=T9_q50 if T8_q39==.
replace T8_q40=T9_q51 if T8_q40==.
replace T8_q41=T9_q52 if T8_q41==.
replace T8_q42=T9_q53 if T8_q42==.
replace T8_q43=T9_q54 if T8_q43==.
replace T8_q44=T9_q55 if T8_q44==.

foreach var of varlist T8_q35-T8_q43 {
 recode `var' (1=1) (2=2) (3=3) (4=4) (5=5) (96=.) (98=.) (99=.), gen(rc_`var'_withmiss)
 }

* This item is reverse coded
foreach var of varlist T8_q44 {
 recode `var' (1=5) (2=4) (3=3) (4=2) (5=1) (96=.) (98=.) (99=.), gen(rc_`var'_withmiss)
} 

gen survey_scale=rc_T8_q35_withmiss+rc_T8_q36_withmiss+rc_T8_q37_withmiss+rc_T8_q38_withmiss+rc_T8_q39_withmiss+rc_T8_q40_withmiss+rc_T8_q41_withmiss+rc_T8_q42_withmiss+rc_T8_q43_withmiss+rc_T8_q44_withmiss
 
ttest survey_scale, by(voter_not_voting)
regress survey_scale voter_not_voting
outreg2 using Tables\S2_SurveyResponses.out, se bracket tdec(3) ctitle("Scale") replace

foreach var of varlist rc_T8_q35_withmiss- rc_T8_q44_withmiss {
 ttest `var', by(voter_not_voting)
 regress `var' voter_not_voting
 outreg2 using Tables\S2_SurveyResponses.out, se bracket tdec(3) append
}

*******************************************************
* Interact state indicators with all covariates
*******************************************************

levelsof vf_state, local(statelist)
qui foreach st of local statelist {
 foreach var of varlist d_yearssincereg d_yearssincereg_miss d_electiondayage d_gender_male d_gender_unknown d_race_black d_race_latino d_race_miss d_race_other d_genvotes d_primvotes d_specvotes {
  local templabel : var label `var'
  gen Z_`st'_`var'=(vf_state=="`st'") * `var'
  local temp="`st'-`templabel'"
  label var Z_`st'_`var' "`temp'"
  summ Z_`st'_`var'
  if r(sd)==0 | r(sd)==. {
   drop Z_`st'_`var' 
  } 
 }
}

*******************************************************
* Table 1 Analysis, including saving underlying Regression results
*******************************************************

* Create underyling propensity to vote score based on voting condition behavior
logit voted_2014_primary Z_* i.strata Z_* if t_labeledasvoting ==1 [pweight=weight_earlystatestreats], robust
predict predicted_turnout_rate

* Capture results in these variables
gen modelnum=_n
gen modelname=""
label var modelname "Sample"
gen propvoter=""
label var propvoter "Proportion Voting, Voter Treatment"
gen propvoting=""
label var propvoting "Proportion Voting, Voting Treatment"
gen diffprtest=""
label var diffprtest "Difference of Proportions (Voter - Voting) [Standard Error]"
gen diffreg=""
label var diffreg "Regression Estimate of Difference (Voter - Voting) [Standard Error]"
gen numobs=""
label var numobs "Number of Observations (Voter, Voting)"
local modelctr=1

* This is the name used for the outreg table
local tablename="SI_RR_Table1"

* Define Model name and sample restriction
local modelname="Entire Sample"
local modelrestriction=`""'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="State=Michigan"
local modelrestriction=`"if vf_state=="MI""'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="State=Missouri"
local modelrestriction=`"if vf_state=="MO""'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="State=Tennessee"
local modelrestriction=`"if vf_state=="TN""'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="No Competitive House Primary"
local modelrestriction=`"if comp_either_primary==0"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Either House Primary Competitive"
local modelrestriction=`"if comp_either_primary==1"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Ever Voters"
local modelrestriction=`"if (strata_sum~=1 & strata_sum ~=2)"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Have Voted in Primary"
local modelrestriction=`"if strata_sum==5 | strata_sum==6"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Have Voted, but Never in Primary"
local modelrestriction=`"if strata_sum==3 | strata_sum==4"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="No Prior History of Voting"
local modelrestriction=`"if strata_sum==1 | strata_sum==2"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Predicted turnout > 70%"
local modelrestriction=`"if predicted_turnout_rate>.70"'

include 02_Subprogram_RegressionPRTests.do

* At the very end, spit out the results into an excel file
export excel modelname-numobs if modelname~="" using tables\Table1_SummaryResultsTable.xls, replace firstrow(varlabels)  
drop modelnum-numobs

*******************************************************
* Table S4 Part A Robustness Analysis, including saving underlying Regression results
*  This is defining treatment as answering election awareness question
*******************************************************

*Treatment assigned if get to through first question (aware of election)
gen alt_voter_not_voting=0 if t_labeledasvoting==1 & T8_q34~=99
replace alt_voter_not_voting=1 if t_labeledasvoter==1 & T9_q45~=99

* Capture results in these variables
gen modelnum=_n
gen modelname=""
label var modelname "Sample"
gen propvoter=""
label var propvoter "Proportion Voting, Voter Treatment"
gen propvoting=""
label var propvoting "Proportion Voting, Voting Treatment"
gen diffprtest=""
label var diffprtest "Difference of Proportions (Voter - Voting) [Standard Error]"
gen diffreg=""
label var diffreg "Regression Estimate of Difference (Voter - Voting) [Standard Error]"
gen numobs=""
label var numobs "Number of Observations (Voter, Voting)"
local modelctr=1

* This is the name used for the outreg table
local tablename="SI_RegressionResults_TableS4_PartA"

* Define Model name and sample restriction
local modelname="Entire Sample"
local modelrestriction=`"if alt_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="State=Michigan"
local modelrestriction=`"if vf_state=="MI" & alt_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="State=Missouri"
local modelrestriction=`"if vf_state=="MO" & alt_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="State=Tennessee"
local modelrestriction=`"if vf_state=="TN" & alt_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="No Competitive House Primary"
local modelrestriction=`"if comp_either_primary==0 & alt_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Either House Primary Competitive"
local modelrestriction=`"if comp_either_primary==1 & alt_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Ever Voters"
local modelrestriction=`"if (strata_sum~=1 & strata_sum ~=2) & alt_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Have Voted in Primary"
local modelrestriction=`"if (strata_sum==5 | strata_sum==6) & alt_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Have Voted, but Never in Primary"
local modelrestriction=`"if (strata_sum==3 | strata_sum==4) & alt_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="No Prior History of Voting"
local modelrestriction=`"if (strata_sum==1 | strata_sum==2) & alt_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Predicted turnout > 70%"
local modelrestriction=`"if predicted_turnout_rate>.70 & alt_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* At the very end, spit out the results into an excel file
export excel modelname-numobs if modelname~="" using tables\TableS4_PartA_SummaryResultsTable.xls, replace firstrow(varlabels)  
drop modelnum-numobs

*******************************************************
* Table S4 Part B Robustness Analysis, including saving underlying Regression results
*  This is defining treatment as completing the 10 item survey
*******************************************************

*Treatment assigned if get to last question (varies by treatment)
gen alt2_voter_not_voting=0 if t_labeledasvoting==1 & T8_q44~=.
replace alt2_voter_not_voting=1 if t_labeledasvoter==1 & T9_q55~=.

* Capture results in these variables
gen modelnum=_n
gen modelname=""
label var modelname "Sample"
gen propvoter=""
label var propvoter "Proportion Voting, Voter Treatment"
gen propvoting=""
label var propvoting "Proportion Voting, Voting Treatment"
gen diffprtest=""
label var diffprtest "Difference of Proportions (Voter - Voting) [Standard Error]"
gen diffreg=""
label var diffreg "Regression Estimate of Difference (Voter - Voting) [Standard Error]"
gen numobs=""
label var numobs "Number of Observations (Voter, Voting)"
local modelctr=1

* This is the name used for the outreg table
local tablename="SI_RegressionResults_TableS4_PartB"

* Define Model name and sample restriction
local modelname="Entire Sample"
local modelrestriction=`"if alt2_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="State=Michigan"
local modelrestriction=`"if vf_state=="MI" & alt2_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="State=Missouri"
local modelrestriction=`"if vf_state=="MO" & alt2_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="State=Tennessee"
local modelrestriction=`"if vf_state=="TN" & alt2_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="No Competitive House Primary"
local modelrestriction=`"if comp_either_primary==0 & alt2_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Either House Primary Competitive"
local modelrestriction=`"if comp_either_primary==1 & alt2_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Ever Voters"
local modelrestriction=`"if (strata_sum~=1 & strata_sum ~=2) & alt2_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Have Voted in Primary"
local modelrestriction=`"if (strata_sum==5 | strata_sum==6) & alt2_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Have Voted, but Never in Primary"
local modelrestriction=`"if (strata_sum==3 | strata_sum==4) & alt2_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="No Prior History of Voting"
local modelrestriction=`"if (strata_sum==1 | strata_sum==2) & alt2_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Predicted turnout > 70%"
local modelrestriction=`"if predicted_turnout_rate>.70 & alt2_voter_not_voting~=."'

include 02_Subprogram_RegressionPRTests.do

* At the very end, spit out the results into an excel file
export excel modelname-numobs if modelname~="" using tables\TableS4_PartB_SummaryResultsTable.xls, replace firstrow(varlabels)  
drop modelnum-numobs

*******************************************************
* Table S4 Part C Robustness Analysis, including saving underlying Regression results
*  This is restricting analysis to those completing survey the day before the election
*******************************************************

* Note that nobody is contacted the day before in Tennessee because the election was on a Thursday and we had exhausted our budget
tab date vf_state
gen contact_daybefore=1 if (vf_state=="MI" & date=="08/04/2014") | (vf_state=="MO" & date=="08/04/2014")

* Capture results in these variables
gen modelnum=_n
gen modelname=""
label var modelname "Sample"
gen propvoter=""
label var propvoter "Proportion Voting, Voter Treatment"
gen propvoting=""
label var propvoting "Proportion Voting, Voting Treatment"
gen diffprtest=""
label var diffprtest "Difference of Proportions (Voter - Voting) [Standard Error]"
gen diffreg=""
label var diffreg "Regression Estimate of Difference (Voter - Voting) [Standard Error]"
gen numobs=""
label var numobs "Number of Observations (Voter, Voting)"
local modelctr=1

* This is the name used for the outreg table
local tablename="SI_RegressionResults_TableS4_PartC"

* Define Model name and sample restriction
local modelname="Entire Sample (Missouri and Michigan)"
local modelrestriction=`"if alt2_voter_not_voting~=. & contact_daybefore==1"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="State=Michigan"
local modelrestriction=`"if vf_state=="MI" & alt2_voter_not_voting~=. & contact_daybefore==1"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="State=Missouri"
local modelrestriction=`"if vf_state=="MO" & alt2_voter_not_voting~=. & contact_daybefore==1"'

include 02_Subprogram_RegressionPRTests.do

*Skip this regression because there are no cases from Tennessee
/* Define Model name and sample restriction
local modelname="State=Tennessee"
local modelrestriction=`"if vf_state=="TN" & alt2_voter_not_voting~=. & contact_daybefore==1"'

include 02_Subprogram_RegressionPRTests.do
*/

* Define Model name and sample restriction
local modelname="No Competitive House Primary"
local modelrestriction=`"if comp_either_primary==0 & alt2_voter_not_voting~=. & contact_daybefore==1"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Either House Primary Competitive"
local modelrestriction=`"if comp_either_primary==1 & alt2_voter_not_voting~=. & contact_daybefore==1"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Ever Voters"
local modelrestriction=`"if (strata_sum~=1 & strata_sum ~=2) & alt2_voter_not_voting~=. & contact_daybefore==1"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Have Voted in Primary"
local modelrestriction=`"if (strata_sum==5 | strata_sum==6) & alt2_voter_not_voting~=. & contact_daybefore==1"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Have Voted, but Never in Primary"
local modelrestriction=`"if (strata_sum==3 | strata_sum==4) & alt2_voter_not_voting~=. & contact_daybefore==1"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="No Prior History of Voting"
local modelrestriction=`"if (strata_sum==1 | strata_sum==2) & alt2_voter_not_voting~=. & contact_daybefore==1"'

include 02_Subprogram_RegressionPRTests.do

* Define Model name and sample restriction
local modelname="Predicted turnout > 70%"
local modelrestriction=`"if predicted_turnout_rate>.70 & alt2_voter_not_voting~=. & contact_daybefore==1"'

include 02_Subprogram_RegressionPRTests.do

* At the very end, spit out the results into an excel file
export excel modelname-numobs if modelname~="" using tables\TableS4_PartC_SummaryResultsTable.xls, replace firstrow(varlabels)  
drop modelnum-numobs

* effect of voting and voter treatments compared to placebo for subsample with baseline turnout rate > .7, conditioned on completion of placebo script (reported in footnote)
regress voted_2014_primary t_labeledasvot* i.strata Z_* if predicted_turnout_rate>.70 & (alt2_voter_not_voting~=. | (t_placebo ==1 &  T1_q1==1)) & contact_daybefore==1 [pweight=weight_earlystatestreats], robust 

*******************************************************
* Figure 1 Analysis, Comparative Message Effectiveness
*******************************************************

regress voted_2014_primary t_info_only t_labeledasvoter t_labeledasvoting i.strata Z_* [pweight=weight_earlystatestreats], robust
local modelntext=string(`e(N)',"%9.0f") 

qui summ voted_2014_primary [aweight=weight_earlystatestreats] if a_phone_treat_relplacebo_passed==0 & e(sample)
local placebo_turnout=100*r(mean)
local placeboturnoutastext=string(`placebo_turnout',"%9.1f")

gen tvar=.
gen beta=.
gen beta_lowci=.
gen beta_hici=.

replace tvar=3 in 1
replace beta= _b[t_info_only] in 1
replace beta_lowci=(_b[t_info_only] - 1.96*_se[t_info_only]) in 1
replace beta_hici=(_b[t_info_only] + 1.96*_se[t_info_only]) in 1

replace tvar=1 in 2
replace beta= _b[t_labeledasvoter] in 2
replace beta_lowci=(_b[t_labeledasvoter] - 1.96*_se[t_labeledasvoter]) in 2
replace beta_hici=(_b[t_labeledasvoter] + 1.96*_se[t_labeledasvoter]) in 2

replace tvar=2 in 3
replace beta= _b[t_labeledasvoting] in 3
replace beta_lowci=(_b[t_labeledasvoting] - 1.96*_se[t_labeledasvoting]) in 3
replace beta_hici=(_b[t_labeledasvoting] + 1.96*_se[t_labeledasvoting]) in 3

label define tvar_lab 3 "GOTV Message" 1 "Voter (Noun)" 2 "Voting (Verb)"
label values tvar tvar_lab

gen betaastext=string(beta,"%9.3f")
replace betaastext="" if beta==.
gen temp2=.002

twoway (bar beta tvar) (rcap beta_hici beta_lowci tvar, lcolor(black) msize(medium)) (scatter temp2 tvar, mlabel(betaastext) msymbol(none) mlabsize(vsmall) mlabcolor(black) mlabposition(0)), ytitle("Estimated Treatment Effect (Relative to Placebo)", size(vsmall)) yscale(range(0 .04)) ylabel(0(.01).04, labsize(vsmall)) yline(0) xtitle("") xlabel(#3, noticks labels angle(forty_five) valuelabel labsize(vsmall) labcolor(black) labgap(small)) note("Among Those Contacted, N=`modelntext'. Placebo group turnout is `placeboturnoutastext'%.", size(vsmall)) legend(off)  scheme(s1mono) xsize(3) ysize(4) name(Figure1, replace)
graph export Figure1.pdf, as(pdf) replace

*Pooled effect of either voting/voter treatment (reported in text).
gen eithervotingvoter=t_labeledasvoter+t_labeledasvoting
regress voted_2014_primary t_info_only eithervotingvoter i.strata Z_* [pweight=weight_earlystatestreats], robust

*GOTV Message - Pooled noun/verb treatment (lincom test)
lincom t_info_only-eithervotingvoter

*******************************************************
* Table S3. Regression Models for Table 1
*******************************************************

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats], robust
outreg2 using "Tables\TableS3_voter_vs_voted.out", se bracket dec(3) label  ctitle("Entire Sample") replace

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if vf_state=="MI", robust
outreg2 using "Tables\TableS3_voter_vs_voted.out", se bracket dec(3) label  ctitle("State=Michigan") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if vf_state=="MO", robust
outreg2 using "Tables\TableS3_voter_vs_voted.out", se bracket dec(3) label  ctitle("State=Missouri") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if vf_state=="TN", robust
outreg2 using "Tables\TableS3_voter_vs_voted.out", se bracket dec(3) label  ctitle("State=Tennessee") append

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if comp_either_primary==0, robust
outreg2 using "Tables\TableS3_voter_vs_voted.out", se bracket dec(3) label  ctitle("No Competitive House Primary") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if comp_either_primary==1, robust
outreg2 using "Tables\TableS3_voter_vs_voted.out", se bracket dec(3) label  ctitle("Either House Primary Competitive") append

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if strata_sum~=1 & strata_sum ~=2, robust
outreg2 using "Tables\TableS3_voter_vs_voted.out", se bracket dec(3) label  ctitle("Ever Voters") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if (strata_sum==5 | strata_sum==6), robust
outreg2 using "Tables\TableS3_voter_vs_voted.out", se bracket dec(3) label  ctitle("Have Voted in Primary") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if (strata_sum==3 | strata_sum==4), robust
outreg2 using "Tables\TableS3_voter_vs_voted.out", se bracket dec(3) label  ctitle("Have Voted, but Never in Primary") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if (strata_sum==1 | strata_sum==2), robust
outreg2 using "Tables\TableS3_voter_vs_voted.out", se bracket dec(3) label  ctitle("No Prior History of Voting") append

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if predicted_turnout_rate>.70, robust
outreg2 using "Tables\TableS3_voter_vs_voted.out", se bracket dec(3) label  ctitle("Predicted Turnout > 70%") append

*******************************************************
* Table S5. Regression Models for Table S4, Panel A
*******************************************************

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if alt_voter_not_voting~=., robust
outreg2 using "Tables\TableS5_voter_vs_voted.out", se bracket dec(3) label  ctitle("Entire Sample") replace

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if vf_state=="MI" & alt_voter_not_voting~=., robust
outreg2 using "Tables\TableS5_voter_vs_voted.out", se bracket dec(3) label  ctitle("State=Michigan") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if vf_state=="MO" & alt_voter_not_voting~=., robust
outreg2 using "Tables\TableS5_voter_vs_voted.out", se bracket dec(3) label  ctitle("State=Missouri") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if vf_state=="TN" & alt_voter_not_voting~=., robust
outreg2 using "Tables\TableS5_voter_vs_voted.out", se bracket dec(3) label  ctitle("State=Tennessee") append

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if comp_either_primary==0 & alt_voter_not_voting~=., robust
outreg2 using "Tables\TableS5_voter_vs_voted.out", se bracket dec(3) label  ctitle("No Competitive House Primary") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if comp_either_primary==1 & alt_voter_not_voting~=., robust
outreg2 using "Tables\TableS5_voter_vs_voted.out", se bracket dec(3) label  ctitle("Either House Primary Competitive") append

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if strata_sum~=1 & strata_sum ~=2 & alt_voter_not_voting~=., robust
outreg2 using "Tables\TableS5_voter_vs_voted.out", se bracket dec(3) label  ctitle("Ever Voters") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if (strata_sum==5 | strata_sum==6) & alt_voter_not_voting~=., robust
outreg2 using "Tables\TableS5_voter_vs_voted.out", se bracket dec(3) label  ctitle("Have Voted in Primary") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if (strata_sum==3 | strata_sum==4) & alt_voter_not_voting~=., robust
outreg2 using "Tables\TableS5_voter_vs_voted.out", se bracket dec(3) label  ctitle("Have Voted, but Never in Primary") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if (strata_sum==1 | strata_sum==2) & alt_voter_not_voting~=., robust
outreg2 using "Tables\TableS5_voter_vs_voted.out", se bracket dec(3) label  ctitle("No Prior History of Voting") append

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if predicted_turnout_rate>.70 & alt_voter_not_voting~=., robust
outreg2 using "Tables\TableS5_voter_vs_voted.out", se bracket dec(3) label  ctitle("Predicted Turnout > 70%") append

*******************************************************
* Table S6. Regression Models for Table S4, Panel B
*******************************************************
set more off
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if alt2_voter_not_voting~=., robust
outreg2 using "Tables\TableS6_voter_vs_voted.out", se bracket dec(3) label  ctitle("Entire Sample") replace

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if vf_state=="MI" & alt2_voter_not_voting~=., robust
outreg2 using "Tables\TableS6_voter_vs_voted.out", se bracket dec(3) label  ctitle("State=Michigan") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if vf_state=="MO" & alt2_voter_not_voting~=., robust
outreg2 using "Tables\TableS6_voter_vs_voted.out", se bracket dec(3) label  ctitle("State=Missouri") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if vf_state=="TN" & alt2_voter_not_voting~=., robust
outreg2 using "Tables\TableS6_voter_vs_voted.out", se bracket dec(3) label  ctitle("State=Tennessee") append

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if comp_either_primary==0 & alt2_voter_not_voting~=., robust
outreg2 using "Tables\TableS6_voter_vs_voted.out", se bracket dec(3) label  ctitle("No Competitive House Primary") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if comp_either_primary==1 & alt2_voter_not_voting~=., robust
outreg2 using "Tables\TableS6_voter_vs_voted.out", se bracket dec(3) label  ctitle("Either House Primary Competitive") append

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if strata_sum~=1 & strata_sum ~=2 & alt2_voter_not_voting~=., robust
outreg2 using "Tables\TableS6_voter_vs_voted.out", se bracket dec(3) label  ctitle("Ever Voters") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if (strata_sum==5 | strata_sum==6) & alt2_voter_not_voting~=., robust
outreg2 using "Tables\TableS6_voter_vs_voted.out", se bracket dec(3) label  ctitle("Have Voted in Primary") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if (strata_sum==3 | strata_sum==4) & alt2_voter_not_voting~=., robust
outreg2 using "Tables\TableS6_voter_vs_voted.out", se bracket dec(3) label  ctitle("Have Voted, but Never in Primary") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if (strata_sum==1 | strata_sum==2) & alt2_voter_not_voting~=., robust
outreg2 using "Tables\TableS6_voter_vs_voted.out", se bracket dec(3) label  ctitle("No Prior History of Voting") append

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if predicted_turnout_rate>.70 & alt2_voter_not_voting~=., robust
outreg2 using "Tables\TableS6_voter_vs_voted.out", se bracket dec(3) label  ctitle("Predicted Turnout > 70%") append

*******************************************************
* Table S7. Regression Models for Table S4, Panel C
*******************************************************

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if alt2_voter_not_voting~=. & contact_daybefore==1, robust
outreg2 using "Tables\TableS7_voter_vs_voted.out", se bracket dec(3) label  ctitle("Entire Sample") replace

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if vf_state=="MI" & alt2_voter_not_voting~=. & contact_daybefore==1, robust
outreg2 using "Tables\TableS7_voter_vs_voted.out", se bracket dec(3) label  ctitle("State=Michigan") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if vf_state=="MO" & alt2_voter_not_voting~=. & contact_daybefore==1, robust
outreg2 using "Tables\TableS7_voter_vs_voted.out", se bracket dec(3) label  ctitle("State=Missouri") append
/*no obs for TN.
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if vf_state=="TN" & alt2_voter_not_voting~=. & contact_daybefore==1, robust
outreg2 using "Tables\TableS7_voter_vs_voted.out", se bracket dec(3) label  ctitle("State=Tennessee") append
*/
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if comp_either_primary==0 & alt2_voter_not_voting~=. & contact_daybefore==1, robust
outreg2 using "Tables\TableS7_voter_vs_voted.out", se bracket dec(3) label  ctitle("No Competitive House Primary") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if comp_either_primary==1 & alt2_voter_not_voting~=. & contact_daybefore==1, robust
outreg2 using "Tables\TableS7_voter_vs_voted.out", se bracket dec(3) label  ctitle("Either House Primary Competitive") append

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if strata_sum~=1 & strata_sum ~=2 & alt2_voter_not_voting~=. & contact_daybefore==1, robust
outreg2 using "Tables\TableS7_voter_vs_voted.out", se bracket dec(3) label  ctitle("Ever Voters") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if (strata_sum==5 | strata_sum==6) & alt2_voter_not_voting~=. & contact_daybefore==1, robust
outreg2 using "Tables\TableS7_voter_vs_voted.out", se bracket dec(3) label  ctitle("Have Voted in Primary") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if (strata_sum==3 | strata_sum==4) & alt2_voter_not_voting~=. & contact_daybefore==1, robust
outreg2 using "Tables\TableS7_voter_vs_voted.out", se bracket dec(3) label  ctitle("Have Voted, but Never in Primary") append
regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if (strata_sum==1 | strata_sum==2) & alt2_voter_not_voting~=. & contact_daybefore==1, robust
outreg2 using "Tables\TableS7_voter_vs_voted.out", se bracket dec(3) label  ctitle("No Prior History of Voting") append

regress voted_2014_primary voter_not_voting i.strata Z_* [pweight=weight_earlystatestreats] if predicted_turnout_rate>.70 & alt2_voter_not_voting~=. & contact_daybefore==1, robust
outreg2 using "Tables\TableS7_voter_vs_voted.out", se bracket dec(3) label  ctitle("Predicted Turnout > 70%") append

*******************************************************
* Table S8. Regression Models for Figure 1
*******************************************************

regress voted_2014_primary t_info_only t_labeledasvoter t_labeledasvoting i.strata Z_* [pweight=weight_earlystatestreats], robust
outreg2 using "Tables\TableS8_figure1.out", se bracket dec(3) label replace

